@@ -197,13 +197,16 @@ int main(int argc, char **argv){
         break;
       default:
         if (clen != 1) break;
-        if (rlen < (sizeof(rbuf) - 1)) rbuf[rlen]= cbuf[0];
         /* allow space for the trailing \0 */
-        rlen++;
+	if (rlen < (sizeof(rbuf) - 1)){
+	  rbuf[rlen]=cbuf[0];
+	  rlen++;
+	}
         break;
       }
       break;
     default:
+      break;
     }
   }
  loop_x:
